@@ -4,10 +4,10 @@
 #
 # Initialization.
 #
-# Sergei Izrailev, 2011-2012, 2022
+# Sergei Izrailev, 2011-2012, 2017-2023
 #-------------------------------------------------------------------------------
 # Copyright 2011-2014 Collective, Inc.
-# Portions are Copyright (C) 2017-2022 Jabiru Ventures LLC
+# Portions are Copyright (C) 2017-2023 Jabiru Ventures LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -31,7 +31,7 @@ tictoc_pkg_env <- new.env(parent = emptyenv())
 {
    tictoc_pkg_env$.ticmsg <- Stack()
    tictoc_pkg_env$.tictoc <- Stack()
-   tictoc_pkg_env$.ticlog <- List()
+   tictoc_pkg_env$.ticlog <- StackList()
 }
 
 #-------------------------------------------------------------------------------
